@@ -1,9 +1,11 @@
 import os
 import shutil
 import requests
+import git
 
 from columnar import columnar
 from pathlib import Path
+from git import Repo
 
 from slai.clients.model import get_model_client
 from slai.clients.cli import get_cli_client
@@ -33,7 +35,7 @@ def _list_model_versions(model_versions):
 
 
 def _create_local_version_path(
-    *, model_name, new_model_version_id, previous_model_version_id
+    *, model_name, new_model_version_id, previous_model_version_id, new_version
 ):
     log.action("Copying existing model notebook...")
 
@@ -55,6 +57,23 @@ def _create_local_version_path(
         f_out.write(_text)
 
 
+def _commit_model_version(*, model_name, model_version_id, model_version_name):
+    cwd = Path.cwd()
+    repo = Repo.init(cwd)
+    repo.git.add([f"models/{model_name}/{model_version_id}"])
+    repo.git.add([f"handlers/{model_name}/*"])
+    repo.index.commit(f"created model version: {model_name}/{model_version_name}")
+
+    try:
+        log.action("Pushing state to git...")
+        repo.git.push("origin", "master")
+        log.action("Pushed to git.")
+    except (ValueError, git.exc.GitCommandError):
+        log.warn(
+            "WARNING: No remote is configured for this project, not pushing commits."
+        )
+
+
 def checkout_model_version(model_name, version_name=None):
     log.action(f"Retrieving model versions for model: {model_name}")
 
@@ -121,6 +140,13 @@ def checkout_model_version(model_name, version_name=None):
                 model_name=model_name,
                 new_model_version_id=model_version_id_to_checkout,
                 previous_model_version_id=model_version_id,
+                new_version=model_version,
+            )
+
+            _commit_model_version(
+                model_name=model_name,
+                model_version_id=model_version["id"],
+                model_version_name=model_version["name"],
             )
 
             log.action(f"Checked out model version: {model_version['name']}")
