@@ -1,11 +1,13 @@
 import click
 import time
+import requests
 
 from pathlib import Path
 from slai.clients.model import get_model_client
 from slai.clients.project import get_project_client
 
 from slai_cli import log
+from slai_cli.errors import handle_error
 from slai_cli.create.local_config_helper import LocalConfigHelper
 from slai_cli.modules.model_watcher import ModelWatcher
 from slai_cli.modules.drive_client import DriveClient
@@ -52,7 +54,17 @@ def open_model(model_name, watch):
     project_name = project["name"]
     project_id = project["id"]
 
-    model_client = get_model_client(model_name=model_name, project_name=project_name)
+    try:
+        model_client = get_model_client(
+            model_name=model_name, project_name=project_name
+        )
+    except requests.exceptions.HTTPError as e:
+        if e.response.status_code == 400:
+            error_msg = e.response.json()["detail"]["non_field_errors"][0]
+            handle_error(error_msg=error_msg)
+            return None
+        else:
+            raise
 
     local_model_config = local_config_helper.get_local_model_config(
         model_name=model_name, model_client=model_client
