@@ -1,8 +1,11 @@
+import requests
+
 from slai.clients.project import get_project_client
 from slai.clients.cli import get_cli_client
 from slai.clients.model import get_model_client
 
 from slai_cli import log
+from slai_cli.errors import handle_error
 from slai_cli.modules.docker_client import DockerClient
 from slai_cli.modules.deployment_checks import check_handler_imports
 from slai_cli.create.local_config_helper import LocalConfigHelper
@@ -35,9 +38,17 @@ def test_model(*, model_name):
         log.warn("ERROR: Unable to connect to docker, is it installed/running?")
         return
 
-    model_client = get_model_client(
-        model_name=model_name, project_name=project_client.get_project_name()
-    )
+    try:
+        model_client = get_model_client(
+            model_name=model_name, project_name=project_name
+        )
+    except requests.exceptions.HTTPError as e:
+        if e.response.status_code == 400:
+            error_msg = e.response.json()["detail"]["non_field_errors"][0]
+            handle_error(error_msg=error_msg)
+            return None
+        else:
+            raise
 
     local_config_helper = LocalConfigHelper()
     local_config = local_config_helper.get_local_config()
