@@ -71,10 +71,13 @@ class DockerClient:
     def __init__(self, *, project_name, project_id):
         self.project_name = project_name
         self.project_id = project_id
-        self.client = docker.from_env()
-        self.docker_api_client = docker.APIClient(
-            base_url="unix://var/run/docker.sock"
-        )  # TODO: support other platforms
+        try:
+            self.client = docker.from_env()
+            self.docker_api_client = docker.APIClient(
+                base_url="unix://var/run/docker.sock"
+            )  # TODO: support other platforms
+        except docker.errors.DockerException:
+            raise RuntimeError("unable_to_launch_container")
 
         self._connect_to_container()
 
